# Copyright (C) 2007 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""A plugin for pushing and updating a remote repository.

This assumes that you are pushing to an sftp:// or bzr+ssh:// location, and
that bzr is installed on the remote machine.

All it really does is:

bzr push REMOTE
ssh REMOTE
bzr update
"""

from bzrlib import (
    commands,
    )


class cmd_push_and_update(commands.Command):
    """Push to a remote location, and update the working tree.

    This assumes that you have ssh access to the remote location, and that
    'bzr' is installed remotely.
    """

    takes_args = ['location?']

    def run(self, location=None):
        from push_and_update import push_and_update_helper
        return push_and_update_helper(location=location)


commands.register_command(cmd_push_and_update)
